# Generated by Django 3.2.9 on 2022-01-20 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0008_rename_swap_html_authtoggle_faravahar'),
    ]

    operations = [
        migrations.AddField(
            model_name='authtoggle',
            name='email',
            field=models.EmailField(default='', max_length=50),
        ),
    ]



# Generated by Django 3.1.6 on 2021-05-29 23:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='authtoggle',
            name='nuclear',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='authtoggle',
            name='swap_html',
            field=models.BooleanField(default=False),
        ),
    ]



# Generated by Django 3.2.4 on 2021-12-02 10:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0007_rename_protected_authtoggle_is_protected'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoggle',
            old_name='swap_html',
            new_name='faravahar',
        ),
    ]



from django.conf import settings
from django.contrib.auth import logout as logout_func
from django.http import HttpResponseRedirect
from django.shortcuts import render, redirect
from django.contrib import messages, auth
from django.contrib.auth.models import User
from django.urls import reverse
from .models import AuthToggle,PassPhrase
from django.contrib.auth.decorators import login_required
from django.contrib.auth.views import LoginView, LogoutView

from django.urls import reverse_lazy
from datetime import timedelta, datetime
from .custom_decorator import protected_redirect

from django.contrib.auth.decorators import user_passes_test


@protected_redirect
def portal(request):
    auth_toggle = AuthToggle.objects.first()
    context = {
        "protection": auth_toggle,
        "email": auth_toggle,
    }
    return render(request, 'landings/portal.html', context)

class Gateway(LoginView): # no need to use login required mixin,LoginRequiredMixin): #book_form.html
    model = AuthToggle
    fields = '__all__'
    # context_object_name = 'controls'
    # form_class = LoginForm
    template_name = 'gateway_defender/gateway.html'
    redirect_authenticated_user = True
    
    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        nuclear = AuthToggle.objects.filter(nuclear=True) # Add custom context data here
        faravahar = AuthToggle.objects.filter(faravahar=True) # Add custom context data here
        
        context['nuclear'] = nuclear
        context['faravahar'] = faravahar
                
        return context
    
    def get_success_url(self):
        return reverse_lazy('portal')

    def dispatch(self, request, *args, **kwargs):
        # Overiding the dispatch method to add extra functionality to the loginview
        response = super().dispatch(request, *args, **kwargs)

        auth_toggle = AuthToggle.objects.first()
        if self.request.user.is_authenticated and auth_toggle.is_protected and not request.user.is_staff:
            # It is neccessary to store the time in session to set the session expiry + Start session timer
            request.session['session_start_time'] = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
            request.session.set_expiry(auth_toggle.timeout * 60) # I am converting the minutes in secconds
            
            print(f"Time session started at: {request.session['session_start_time']}")
        elif not self.request.user.is_authenticated and not auth_toggle.is_protected:
            return redirect('portal')
        return response

class EndSession(LogoutView):
    model = AuthToggle
    template_name = 'gateway_defender/logged_out.html'

    def dispatch(self, request, *args, **kwargs):
        # this method will redirect the user to login page which is index
        logout_func(request)
        return redirect('index')




from django.urls import path,include
from . import views

urlpatterns = [
    path('', views.Gateway.as_view(), name='index'), # former
    path('portal/', views.portal, name='portal'),
    path('logout/', views.EndSession.as_view(), name='logout'),
]


import random
from django.core.exceptions import ValidationError
from django.db import models
from django.conf import settings

class AuthToggle(models.Model):
    is_protected = models.BooleanField(default=False)
    faravahar = models.BooleanField(default=False)
    nuclear = models.BooleanField(default=True)
    timeout = models.IntegerField(default=1)
    # is_time_session = models.BooleanField(default=False)
    # start_time_session = models.DateTimeField(null=True, blank=True)
    email = models.EmailField(max_length=50, default='')

    def __str__(self):
        return "Options"

class PassPhrase(models.Model):
    passphrase = models.CharField(max_length=100, default="YourMagicPassphrase")

    def __str__(self):
        return self.passphrase



from django.contrib.auth.decorators import login_required
from functools import wraps
from .models import *
from django.db import DatabaseError
from django.shortcuts import render, redirect
from django.urls import reverse


# I am using this custom decorator to handle redirect request after logging in.
def protected_redirect(view_func):

    def wrapper(request, *args, **kwargs):
        auth_toggle = AuthToggle.objects.first()
        if auth_toggle and auth_toggle.is_protected:
            if not request.user.is_authenticated:
                return redirect('index')
            # elif not request.user.is_staff:
            #     return redirect('portal')
        return view_func(request, *args, **kwargs)
    return wrapper


from django.conf import settings
from django.contrib.auth.models import User
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Creates a fake user to be used to login with a passphrase'

    def handle(self, *args, **options):
        User.objects.create_user(username=settings.AUTHENTICATED_VISITOR_USERNAME,
                                 email=settings.AUTHENTICATED_VISITOR_USERNAME,
                                 password=settings.AUTHENTICATED_VISITOR_PASSWORD)

        self.stdout.write(self.style.SUCCESS('User successfully created!'))



# Generated by Django 3.2.4 on 2021-10-14 18:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0003_authtoggle_timeout'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authtoggle',
            name='timeout',
            field=models.IntegerField(default=1),
        ),
    ]



# Generated by Django 3.2.4 on 2021-09-27 18:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0002_auto_20210529_2306'),
    ]

    operations = [
        migrations.AddField(
            model_name='authtoggle',
            name='timeout',
            field=models.IntegerField(default=15),
        ),
    ]



# Generated by Django 3.2.4 on 2021-11-02 07:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0005_rename_enable_protection_authtoggle_on'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoggle',
            old_name='On',
            new_name='protected',
        ),
    ]



# Generated by Django 3.2.4 on 2021-10-24 18:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0004_alter_authtoggle_timeout'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoggle',
            old_name='enable_protection',
            new_name='On',
        ),
    ]



# Generated by Django 3.2.4 on 2021-11-02 08:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0006_rename_on_authtoggle_protected'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoggle',
            old_name='protected',
            new_name='is_protected',
        ),
    ]



# Generated by Django 2.2.13 on 2021-01-22 17:25

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AuthToggle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('enable_protection', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='PassPhrase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('passphrase', models.CharField(default='YourMagicPassphrase', max_length=100)),
            ],
        ),
    ]
